package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````2",```````!``````````("A````
M`````````$``.``(`$``&0`8``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````&24````````9)0`````````
M``$```````$````&````^)H```````#XF@$``````/B:`0``````B`4`````
M``"P%0```````````0```````@````8````(FP````````B;`0``````")L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#XF@```````/B:`0``````^)H!```````(!0``````
M``@%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`7ZV;80(6L<>8*]OE:P)T:?.@CX01````4`````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`,@<````````````````````````
M`P`5``"@`0````````````````#2`@``$@````````````````````````!6
M`P``$@````````````````````````"B`@``$@``````````````````````
M``"I`@``$@````````````````````````!(`P``$@``````````````````
M``````!+`@``$@`````````````````````````1````(```````````````
M``````````#Z`@``$@`````````````````````````2`P``$@``````````
M```````````````Y`P``(@`````````````````````````+`P``$@``````
M``````````````````#R`@``$@````````````````````````"T````$@``
M```````````````````````$`P``$0````````````````````````"#`0``
M$@`````````````````````````Y`@``$@````````````````````````"$
M````$@`````````````````````````,`0``$@``````````````````````
M```;`P``$@````````````````````````"4`@``$@``````````````````
M``````"J`0``$@`````````````````````````!`0``$0``````````````
M``````````#9`@``$@````````````````````````!G`0``$@``````````
M``````````````#C````$0`````````````````````````U`0``$@``````
M``````````````````!0`@``$@````````````````````````!L`P``$@``
M``````````````````````"P`@``$@````````````````````````#"````
M$@````````````````````````"Q`0``$@`````````````````````````B
M`@``$@````````````````````````">`0``$@``````````````````````
M``#P`0``$@````````````````````````!_`@``$@``````````````````
M``````";`@``$@````````````````````````!8`@``$@``````````````
M``````````!A`@``$@`````````````````````````$`@``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````">`P``$0````````````````````````!_`P``(0``
M``````````````````````"'`@``$@````````````````````````!>`P``
M$@````````````````````````"\`0``$0````````````````````````!D
M````$@````````````````````````#$`@``$@``````````````````````
M``!E`P``$@`````````````````````````K!```$@``````````````````
M``````"^`@``$@````````````````````````"3````$@``````````````
M``````````"?````$@````````````````````````!<`0``$@``````````
M``````````````#G`@``$@`````````````````````````B`0``$@``````
M```````````````````1`0``$@````````````````````````!6````$@``
M```````````````````````O`P``$@`````````````````````````6`0``
M$@````````````````````````"3`0``$@````````````````````````#P
M````$@`````````````````````````H`P``$@``````````````````````
M``!U`0``$@````````````````````````!S````$@``````````````````
M```````J`@``$@````````````````````````"-`@``$@``````````````
M``````````!^`P``$0````````````````````````"``P``$0``````````
M```````````````*`@``$@````````````````````````#4````$@``````
M``````````````````!3`0``$@````````````````````````"W`@``$@``
M```````````````````````\````(``````````````````````````1`@``
M$@````````````````````````!R`@``$@````````````````````````!Y
M`@``$@````````````````````````#@`P``$``6`*BP`0``````````````
M```T!```$@`-`-A2````````@``````````"!```$@`.`/Q3````````````
M``````!9!```$@`-``!%````````F`D```````!Y`P``$@`-```A````````
M2`(````````(!```$@`-`.@]````````!`````````#1`P``$``6`("@`0``
M``````````````#'!```$@`-`/`]````````0`(```````#!!```$@`+`,@<
M``````````````````#T!```$@`-`)A.````````0`0```````#%`P``$``6
M`("@`0````````````````!`!```$@`-`#!`````````*`````````!S!```
M$0`/`!!4````````!`````````#S`P``$``6`*BP`0````````````````#K
M`P``$``6`*BP`0````````````````"_!```$@`-`'@\````````.```````
M``#4!```$@`-`/A#````````!`$```````#F!```$@`-`$A#````````B```
M``````!F!```$``5``"@`0````````````````!-!```$@`-`%A`````````
M*`$```````"^`P``$``5`("@`0````````````````"H!```$0`5`'B@`0``
M````"`````````#X`P``$@`-`/A3````````!`````````"8!```$@`-`'A3
M````````@`````````!L!```$@`-`$@C``````````````````!H!```(``5
M``"@`0`````````````````9!```$@`-`-!#````````*`````````#?`P``
M$``6`*BP`0````````````````""!```$@`-``@]````````W`````````"R
M!```$@`-`(!!````````Q`$`````````;&EB<&5R;"YS;RXU+C(V`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI
M8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T
M`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T
M<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK
M`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R
M96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F
M:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?
M7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M86%R8V@V-"YS
M;RXQ`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?
M8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?
M96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!'3$E"0U\R+C$W```````````"``(``@`"``(``@````(``@`"
M``(``@````(````"```````"``(``@````(``````````@`"``(```````,`
M```#``(``@`"``(``P``````!``"``(``@```````@`"``(``@`````````"
M`````@````(``````````@```````P`"``(``@`#```````"`````P`"``(`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``````````0`!`(@#```0````(````)>1E@8```0`
M"@4````````!``$`X`$``!`````@````EY&6!@```P`*!0````````$``0`O
M`@``$`````````"7D98&```"``H%````````^)H!```````#!````````%`D
M`````````)L!```````#!`````````@D````````>)\!```````#!```````
M`/A3````````P)\!```````#!`````````B@`0``````T)\!```````#!```
M`````'A3````````X)\!```````#!``````````A````````"*`!```````#
M!`````````B@`0``````&*`!```````#!````````"!8````````(*`!````
M```#!````````%!4````````,*`!```````#!````````+!5````````.*`!
M```````#!`````````!8````````0*`!```````#!`````````A8````````
M2*`!```````#!````````!!8````````4*`!```````#!````````!A8````
M````8*`!```````#!````````.A7````````:*`!```````#!````````/!7
M````````>*`!```````#!````````"A8````````@)\!```````!!```"0``
M````````````B)\!```````!!```#```````````````D)\!```````!!```
M$```````````````F)\!```````!!```$0``````````````H)\!```````!
M!```&```````````````J)\!```````!!```&P``````````````L)\!````
M```!!```*P``````````````N)\!```````!!```+```````````````R)\!
M```````!!```,```````````````V)\!```````!!```.@``````````````
MZ)\!```````!!```0P``````````````\)\!```````!!```1P``````````
M````^)\!```````!!```3```````````````<)T!```````"!````P``````
M````````>)T!```````"!```!```````````````@)T!```````"!```!0``
M````````````B)T!```````"!```!@``````````````D)T!```````"!```
M!P``````````````F)T!```````"!```"```````````````H)T!```````"
M!```"@``````````````J)T!```````"!```"P``````````````L)T!````
M```"!```#```````````````N)T!```````"!```#0``````````````P)T!
M```````"!```#@``````````````R)T!```````"!```#P``````````````
MT)T!```````"!```$@``````````````V)T!```````"!```$P``````````
M````X)T!```````"!```%```````````````Z)T!```````"!```%0``````
M````````\)T!```````"!```%@``````````````^)T!```````"!```%P``
M`````````````)X!```````"!```&0``````````````")X!```````"!```
M&@``````````````$)X!```````"!```'```````````````&)X!```````"
M!```'0``````````````()X!```````"!```'@``````````````*)X!````
M```"!```'P``````````````,)X!```````"!```(```````````````.)X!
M```````"!```(0``````````````0)X!```````"!```(@``````````````
M2)X!```````"!```(P``````````````4)X!```````"!```)```````````
M````6)X!```````"!```)0``````````````8)X!```````"!```)@``````
M````````:)X!```````"!```)P``````````````<)X!```````"!```*```
M````````````>)X!```````"!```*0``````````````@)X!```````"!```
M*@``````````````B)X!```````"!```*P``````````````D)X!```````"
M!```+@``````````````F)X!```````"!```+P``````````````H)X!````
M```"!```,0``````````````J)X!```````"!```,@``````````````L)X!
M```````"!```,P``````````````N)X!```````"!```-```````````````
MP)X!```````"!```-0``````````````R)X!```````"!```-@``````````
M````T)X!```````"!```-P``````````````V)X!```````"!```.```````
M````````X)X!```````"!```.0``````````````Z)X!```````"!```.P``
M````````````\)X!```````"!```/```````````````^)X!```````"!```
M/0```````````````)\!```````"!```/@``````````````")\!```````"
M!```/P``````````````$)\!```````"!```0```````````````&)\!````
M```"!```00``````````````()\!```````"!```0@``````````````*)\!
M```````"!```1```````````````,)\!```````"!```10``````````````
M.)\!```````"!```2```````````````0)\!```````"!```20``````````
M````2)\!```````"!```2@``````````````4)\!```````"!```2P``````
M````````6)\!```````"!```30``````````````8)\!```````"!```3@``
M````````````:)\!```````"!```3P``````````````_7N_J?T#`)&L`0"4
M_7O!J,`#7]8`````\'N_J=```)`1MD;Y$*(UD2`"']8?(`/5'R`#U1\@`]70
M``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?UM```)`1PD;Y$`(VD2`"
M'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?UM```)`1SD;Y$&(V
MD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1(`(?UM```)`1VD;Y
M$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0`C>1(`(?UM```)`1
MYD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N1OD08C>1(`(?UM``
M`)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```D!'Z1OD0PC>1(`(?
MUM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6T```D!$&1_D0(CB1
M(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@`A_6T```D!$21_D0
M@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#".)$@`A_6T```D!$>
M1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'^1`B.9$@`A_6T```
MD!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0$3)'^1"".9$@`A_6
MT```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0``"0$3Y'^1#B.9$@
M`A_6T```D!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"'];0``"0$4I'^1!"
M.I$@`A_6T```D!%.1_D08CJ1(`(?UM```)`14D?Y$((ZD2`"'];0``"0$59'
M^1"B.I$@`A_6T```D!%:1_D0PCJ1(`(?UM```)`17D?Y$.(ZD2`"'];0``"0
M$6)'^1`".Y$@`A_6T```D!%F1_D0(CN1(`(?UM```)`1:D?Y$$([D2`"'];0
M``"0$6Y'^1!B.Y$@`A_6T```D!%R1_D0@CN1(`(?UM```)`1=D?Y$*([D2`"
M']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1(`(?UK```/`1@D?Y$`(\
MD2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D00CR1(`(?UK```/`1CD?Y
M$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0HCR1(`(?UK```/`1
MFD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B1_D0`CV1(`(?UK``
M`/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```\!&N1_D08CV1(`(?
MUK```/`1LD?Y$((]D2`"']:P``#P$;9'^1"B/9$@`A_6_7NYJ?T#`)'S4P&I
MLP``\+0``/!CWD?YHH<$J:(C`9%D`$#YI#<`^00`@-*@7P"YH4,!D:!S`9&*
M__^7H```\*(``/``]$?Y0NQ'^>$#`JJ"#`"4H```\`#41_D``$`Y8`$`-4O_
M_Y?"``"00%``^4`.`+2T``#P%O__EX#21_D``$"Y3___EQ^$)#F4TD?Y@`)`
MN4O__Y<!Z%,Y(0`?,@'H$SF``D"Y1O__EP+H4SFA7T"Y`P#\DD(``#("Z!,Y
M(10`$;5;`JFW&P#Y(7Q`DS\``^MH"@!4(/!]TS7__Y>E*T#YP@``D-0``)"$
M(@*11SQ`^0,``/`!``#P8V`?D:@`0/DA@!^1A@"`4J)?0+D(#`"I!P0!J5\$
M`'&&!`"Y@`0`^4T!`%0A`(#2Y@"`DB00`!&C>&'XQ,PDBR$$`)%?``%K`V@D
M^$S__U26(@*111``$07,)8OC`P"J`0``L`0`@-+`#D#Y0@P`$;^`'_@AP#*1
M;___E_4#`"J@`P`TEB("D;>3`9'`#D#YZ?[_EP```/#A`Q>J```5D:<$`)0`
M`@"TE"("D8`.0/G-_O^75/__EW/>1_G@`Q4JHC=`^6$"0/E!``'*80,`M;5;
M0JGS4T&IMQM`^?U[QZC``U_6P`I`^>```+3\"P"4[O__%\`.0/EO__^7]0,`
M*N'__Q<```#PX0,7J@`@$Y&+!`"4P`H`^8#\_[3P"P"4XO__%Z$``/````#P
M`$`?D2'D1_DD__^7\_[_E[5;`JD@`(!2MQL`^8/^_Y<=`(#2'@"`TN4#`*KA
M`T#YXB,`D>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(2\1_FZ_O^7\?[_EZ``
M`/``V$?Y0```M.G^_Q?``U_6`````,```)````*1P0``D"$``I$_``#KH```
M5*$``/`AP$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+
M(?Q#DR'\08LA_$&3P0``M*(``/!"_$?Y8@``M$``']8?(`/5P`-?UA\@`]7]
M>[ZI_0,`D?,+`/G3``"08`)".4`!`#6@``#P`,1'^8```+3```"0``1`^5/^
M_Y?8__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];>__\7`````/^#"M&H``#P!.``
MD0G@`9']>P"I_0,`D:)C`)$!W4?Y1R``D2,`0/FC3P'Y`P"`TH$`0+F#A$#X
M(0C`6N&`'_B?``GK8?Q@TV7\:-,FW'C3I1QXDB$<"%/&''"2(0`&JJ/@0ZHA
M``.JX00!^"'^_U1&``B11`!`^4(@`)%#!$#Y11Q`^4$P0/EC``3*7P`&ZR$`
M!<HA``/*(_Q?TV$$`:HA?$"203P`^6'^_U0%$$"I@`!GG@8<0:GA`&>>P@!G
MGH'\0M,A>`2JH_Q;TT`<82XL?$"2@0%GGF,4!:JKOT&I*C./TDI0J_()$$#Y
M#0!FGJ``9YYK`0J+HOQ"TR`<8BY">`6J[P$*BR$``LJC02.+L!=`^6,`"XM-
M?$"28P`)"Q`""HL.`&:>:_Q;TVL5`ZHA``.*(0`,RK%C0/DA``:+S@$'BR$`
M$(O.`0^+;_Q"TVL!#@OC>0.J;OU;TT(``\I"``N*SA4+JLX!`0M!``W*KPM#
MJ7#]0M,0>@NJ(0`,B^\!"HML`!#*(0`/BV-\0)++_5O3C`$.BL_]0M-K%0ZJ
M[WD.JHP!`\IK`0$+3@`*BXP!#8L-`@_*`7Y`DHP!#HMB_5O3K0$+BF[]0M-"
M%`NJK0$!RLMY"ZI"``P+K0$#B^P!"\KC?4"2L#]$J4[\6]/.%0*JC`$"BA`"
M"HN,`0/*K0$0B^\!"HO.`0T+@0$!BU#\0M/-_5O3`GH"JB$`#XNM%0ZJS_U"
MTZT!`0ML`0+*X7D.JFM]0)*P/T6IC`$.BHP!"\JN_5O3$`(*BX,!`XM,``'*
M8P`0BT)\0)+.%0VJC`$-BLX!`PN,`0+*L/U"TP-Z#:KO`0J+BP$+B\W]6]-K
M`0^+K14.JL_]0M.M`0L++``#RNMY#JJP/T:I(7Q`DHP!#HJN_5O3C`$!RA`"
M"HN"`0*+;``+RD(`$(MC?$"2SA4-JHP!#8K.`0(+C`$#RK#]0M/O`0J+@0$!
MB\S]6],">@VJ(0`/BXP5#JK/_4+3C`$!"VT!`LKA>0ZJ:WU`DK`_1ZFM`0Z*
MK0$+RH[]6],0`@J+HP$#BTT``<IC`!"+0GQ`DLX5#*JM`0R*D/U"T\X!`PL,
M>@RJK0$"RN\!"HLC``S*JP$+B\W]6],A?$"2:P$/B[!#0/FM%0ZJ8P`.BL_]
M0M.M`0L+[WD.JF,``<H.`@J+BP$/RF,``HNB_5O3C'U`DF,`#HNP1T#Y0A0-
MJFL!#8JN_4+30@`#"\YY#:IK`0S*#0(*B^,!#LIK`0&+0?Q;T^]]0))K`0V+
ML$M`^2$4`JIC``**3?Q"TR$`"PNM>0*J8P`/RLL!#<IC``R+(OQ;TPP""HO.
M?4"28P`,BT(4`:IK`0&*L$]`^4(``PMK`0[*+/Q"TXQY`:H0`@J+:P$/BT'\
M6]-K`1"+(10"JE#\0M,A``L+HP$,R@MZ`JIC``**@@$+RJ]30/FM?4"2C'U`
MDD(``8IC``W*0@`,RF,`#HM"``V+[@$*BR_\6].PMTJI8P`.B^\5`:HN_$+3
M[P$#"\YY`:KC_5O3`0(*BV,4#ZI"``&+80$.RD)`(XMK?4"2(0`/BD-\0)(A
M``O*J@$*BR$`#(OM_4+3;/Q;TR$`"HN,%0.JJGD/JBQ`+(NM7T#YP0$*RI!]
M0)(A``)*(G2=TBL`"XLBVZWR;_Q"TZ$!`HL-_EO3XWD#JF$!`8NM%1"J2P$#
MRBU`+8MK`0Q*KWU`DFM!+HOL_5O3+@("BP'^0M-K`0Z+(7@0JHP5#ZIL02R+
ML&=`^6L``<J.?4"2;0$-2A`"`HNJ02J+Z_U"T\W]6]-K>0^J2@$0BZT5#JI-
M02V+L&M`^2H`"\JO?4"22@$,2A`"`HM*02.+[/U;T\/]0M-*`1"+8W@.JHP5
M#ZI,02R+L&]`^6H!`\J.?4"22@$-2A`"`HM!02&+S?U;T^K]0M,A`!"+2GD/
MJJT5#JHM0"V+L'-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"T^S]6],A>`ZJ
M:P$0BXP5#ZIL02R+L'=`^4L!`<J.?4"2;0$-2A`"`HNC02.+Z_U"T\W]6]-K
M>0^J8P`0BZT5#JJP>T#Y;4`MBR,`"\JO?4"2;``,2A`"`HN*02J+P_U"T^S]
M6]-C>`ZJ2@$0BXP5#ZI,02R+L']`^6H!`\J.?4"230$-2A`"`HNA02&+ZOU"
MT\W]6]-*>0^J(0`0BZT5#JHM0"V+L(-`^6$`"LJO?4"2+``,2A`"`HN+02N+
MP?U"T^S]6],A>`ZJ:P$0BXP5#ZIL02R+L(=`^4L!`<J.?4"2;0$-2A`"`HNC
M02.+Z_U"T\W]6]-K>0^J8P`0BZT5#JIM0"V+L(M`^2,`"\JO?4"2;``,2A`"
M`HN*02J+P_U"T^S]6]-C>`ZJ2@$0BXP5#ZI,02R+L(]`^6H!`\J.?4"230$-
M2A`"`HNA02&+ZOU"T\W]6]-*>0^J(0`0BZT5#JHM0"V+80`*RBP`#$K!_4+3
M(7@.JJ]]0)*P.U*IBT$KB^S]6],0`@*+C!4/JFL!$(MK02R+3`$!RG!]0)*-
M`0U*HT$CB^S]0M/-`0*+#OY;TXQY#ZIC``V+SA40JFY`+HLC``S*:P`+2@/^
M0M-C>!"JSWU`DJU#4ZEJ02J+JP$"B^W]6]-*`0N+K14/JDU!+8N*`0/*3@$.
M2NK]0M-*>0^J$`("B\%!(8NK?4"2(0`0BW``"LH-`@U*;OU;TW#]0M/.%0NJ
M"WH+JBY`+HNO0U2IP7U`DJQ!+(LM_%O3[P$"BZT5`:J,`0^+3P$+RHQ!+8ON
M`0Y*C7U`DA`"`HO#02.+KOU;T\X5#:JQ_4+3+_Q"TV,`$(O#`0,+X7D!JBYZ
M#:IP`0'*KT=5J1`"#$K-?4"2+'Q`D@I"*HLA``ZJX@$"BV_\6],A``.*</Q"
MTT(!`HOJ%0.JCP$-BD(!`@L#>@.J(0`/JHJ;E])O?$"2:N.Q\BM`*XLQ`@J+
MP0$#JFL!$8LA``**L0$/BE#\6],A`!&J$!8"JJY'5JE2_$+3"P(+"T)Z`JI0
M?$"2S@$*BR$`#(MC``*J;/U;TW+]0M,A``Z+C!4+JNX!$(IC``N*C`$!"V,`
M#JI!>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:IC``V+DOU"TPT"#HJQNT#Y:Q4,
MJD(`#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JG+]0M-"``^+
ML;]`^<\!#8J,%0NJ(0`+BHP!`@LA``^J0GH+JB$`$(M/?$"2,`(*BXO]6]-C
M``*JDOU"TR$`$(NQPT#YL`$/BFL5#*IC``R*:P$!"V,`$*I!>@RJ8P`.BS!\
M0)(N`@J+;/U;TT(``:IR_4+38P`.B[''0/GN`1"*C!4+JD(`"XJ,`0,+0@`.
MJD-Z"ZI"``V+;GQ`DBT""HN+_5O3(0`#JI+]0M-"``V+L<M`^0T"#HIK%0RJ
M(0`,BFL!`@LA``VJ0GH,JB$`#XM-?$"2+P(*BVS]6]-C``*J<OU"TR$`#XNQ
MST#YSP$-BHP5"ZIC``N*C`$!"V,`#ZI!>@NJ8P`0BR]\0)(P`@J+B_U;TT(`
M`:J2_4+38P`0B['30/FP`0^*:Q4,JD(`#(IK`0,+0@`0JD-Z#*I"``Z+<'Q`
MDBX""HML_5O3(0`#JG+]0M-"``Z+L==`^>X!$(J,%0NJ(0`+BHP!`@LA``ZJ
M0GH+JB$`#8M.?$"2+0(*BXO]6]-C``*JDOU"TR$`#8NQVT#Y#0(.BFL5#*IC
M``R*:P$!"V,`#:I!>@RJ8P`/BRU\0)(O`@J+;/U;TT(``:IR_4+38P`/B['?
M0/G/`0V*C!4+JD(`"XJ,`0,+0@`/JD-Z"ZI"`!"+;WQ`DC`""HN+_5O3(0`#
MJI+]0M-"`!"+L>-`^;`!#XIK%0RJ(0`,BFL!`@LA`!"J0GH,JB$`#HM0?$"2
M+@(*BVS]6]-C``*J<OU"TR$`#HNQYT#Y[@$0BHP5"ZIC``N*C`$!"V,`#JI!
M>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:J2_4+38P`-B['K0/D-`@Z*:Q4,JD(`
M#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JD(`#XNQ[T#YSP$-
MBHP5"ZHA``N*C`$""W+]0M,A``^J0GH+JB$`$(N+_5O3,`(*BR$`$(MK%0RJ
M:P$!"T]\0)*Q!UZI8P`"JK`!#XIC``R*DOU"TV,`$*I,>@RJ,0(*BY!]0))"
M``RJ8P`.BV[]6]/.%0NJ0@`+BF,`$8OQ`1"*PP$#"T(`$:IN_4+3(0`*B\MY
M"ZI"``V+;?Q;TVY]0))"``&+K14#JH$!"ZI20"V+K/M`^0("#HHA``.*37Y`
MDB$``JIB_$+30W@#JHH!"HLA``^+K/U;TV(!`\HA``J+C!4-JJ_]0M,L0"R+
M00`22B$`$(N1?4"2JL-?J<(ZF-)"3+GR*_Y;TTH!`HMK%1&J(0`*B^IY#:HK
M0"N+80`*RF]]0)(A``Q*[?U;TPP"`HLA``Z++OY"T\YY$:HA``R+K14/JDP!
M#LHM0"V+H0=!^;!]0)*+`0M*(0`"BPS^6]-K02.+X_U"TVL!`8N,%1"J87@/
MJFQ!+(NC"T'YRP$!RH]]0))K`0U*8P`"B^W]6]-J02J+"_Y"TVMY$*I*`0.+
MK14/JB,`"\I-02V+J@]!^;!]0))C``Q*2@$"BPS^6]-C0"Z+[OU"TV,`"HN,
M%1"JRGD/JFQ`+(MN`0K*HQ-!^8]]0)+.`0U*8P`"B^W]6]/!02&+#OY"TR$`
M`XNM%0^JPWD0JBU`+8M0`0/*H1=!^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"
MTVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JQM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+
MT/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JA]!^:Y]0)(0`@Q*2@$"B\S]6],#
M0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HR-!^8]]0)(0`@U*8P`"B^W]
M6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H2=!^:Y]0)(0`@Q*(0`"
MB\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JRM!^8]]0)(0`@U*
M:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JB]!^:Y]0)(0
M`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HS-!^8]]
M0)(0`@U*8P`"B^W]6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H3=!
M^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*
MJSM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP
M``O*JC]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`
M+(NO0T'Y8P$*RI!]0))M``U*H4$ABP/^6]/M`0*+S_U"TV,4$*HA``V+[7D.
MJB%`(XNO1T'Y0P$-RBY\0))C``Q*#/Y"T^\!`HN,>1"J:T`KB\/]6]-K`0^+
M8Q0.JK`!#,JO2T'Y8P`+"P$"`4K+_4+3*D`JB^$!`HMB_%O32@$!BT(4`ZIA
M>0ZJ0@`*"R8`!@L(W4?YAP$'"ZD!"0M%``4+@P`#"P8<`:D%#`"I"1``^:%/
M0?D``4#Y(```RH```+7]>T"I_X,*D<`#7]9T^O^7'R`#U?U[O*G]`P"1\PL`
M^8`'`+2B``#0N!\`^4+X1_E8`$#Y.`<`M+43`/D5`(!2`@!`.5_T`'%$&$!Z
M00,`5!,#0/F3!0"TMM\"J;5^0).T#P#Y]P,!JO8#`*KT`QBJX`,3JN(#%:KA
M`Q:J+/K_EX```#5@:G4X'_0`<4`"`%23CD#X\_[_M;370:FVWT*IN!]`^>`#
M$ZKS"T#Y_7O$J,`#7];U`P"JHAY`.%_T`'%$&$!ZH?__5+4"`$OA__\7'R`#
MU90"&,NU!@"1E/Y#D_0"`+ES`A6+X`,3JK@?0/FTUT&IMM]"J?,+0/G]>\2H
MP`-?UK430/FX'T#YYO__%Q,`@-+D__\7$P"`TK@?0/GA__\7_7N\J?T#`)'U
M6P*IM@``T/-3`:FS``#0]0,`JL#>1_ES^D?YM-,`D0$`0/FA'P#Y`0"`TN$#
M%*K@`Q6JK?__E^`!`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`
M^0$``/FA__^UX0,4JN`#%:J?__^78/[_M=;>1_FA'T#YP`)`^2```,J@``"U
M\U-!J?5;0JG]>\2HP`-?U@;Z_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JFU
M``#0]V,#J?0#`*JAWD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JH#Y
M_Y?V`P"JH9,!D>`#%*I^__^7X`<`M/<#`*IY^?^7'P`6ZZ(&`%2X9X"YMP``
MT!CS?=.``D`Y'_0`<0080'J`#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+
M(7Q`D_?Z1_G`"@"1```!B_8"0/F<^?^7P&HX^*`+`+2C9X"Y@`8`D>("0/F!
M`D`Y/_0`<4)X8_@D&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$
M`)&@!X!20```.6`60#@@%``XP/__-0``@%*UWD?YHC=`^:$"0/E!``'*H0@`
MM?-30:GU6T*I]V-#J?U[QZC``U_6``"`TF%J8#CA:B`X``0`D:'__S7P__\7
MMP``T+EK!*F[*P#YX/I'^1@`0/D``T#Y@`4`M.$#&*H``(!2`@``%.`#&2HB
MC$#X&00`$:+__[4`#``1`'Q]DZ$``/`BB$"Y@@(`-2(`@%(BB`"Y7_G_E_L#
M`*K``P"T.G]`D^$#&*I8\WW3X@,8JACY_Y?@^D?Y&P``^5H'`)%_>SKXN6<`
MN;LK0/FY:T2II?__%Q\@`]7A`P"JX`,8JGSY_Y?[`P"JX/I'^1L``/D[`0"T
M.G]`DUCS?=/P__\7`0"`TJ/__Q<``H#2&0"`4MS__Q>Y:T2INRM`^0``@!*X
M__\7N6L$J;LK`/EU^?^7_7NRJ?T#`)'S"P#YLP``T&'>1_DB`$#YHF\`^0(`
M@-+```"TM`\`^?0#`*H!`$`Y00$`-;0/0/ESWD?YH6]`^6`"0/D@``#*P`D`
MM?,+0/G]>\ZHP`-?UK87`/D%^?^7]@,`JN`&`+2W8P.I%P``T!@``-"Z)P#Y
M]T(1D1AC$9&Z8P&1M1,`^>`#%JJ5^?^7``8`M!5,`)'A`Q>JX`,5JFSY_Y<@
M__\TX0,8JN`#%:IH^?^7H/[_-+DC`/G@`Q2JT/C_E_D#`*K@`Q6JS?C_EP``
M&0L`"``1`'Q`DP'Y_Y?E`Q6JY`,4J@,``-!C@!&1^0,`J@(`@)(A`(!2Q?C_
ME^(#&JKA`QFJ``"`4LGX_Y<?!``QH```5*!K0+D`#!02'Q!`<8`"`%3@`QFJ
MH?G_E^`#&:IC^?^7N2-`^=/__Q>T#T#YMA=`^;S__Q<?(`/5X`,6JAOY_Y?@
M`Q2J1?G_E[370:FVWT*IN!]`^;HG0/FR__\7X`,9JJ+__Y?M__\7M-<!J;;?
M`JFXYP.INB<`^1#Y_Y<?(`/5_7N^J?T#`)'S4P&ILP``T/0#`*ISTD?Y8`)`
MN??X_Y<"``B1X0,4J@``@%([^?^7P```-```@%+S4T&I_7O"J,`#7]8?(`/5
M8`)`N>OX_Y<`$$*Y``P4$A\00''@``!48`)`N>7X_Y<`$$*Y``P4$A\H0'$!
M_O]400"`4N`#%*H"^?^7'P``<>`7GQKS4T&I_7O"J,`#7]80"H+2_V,PR^+_
M@=+]>P"I_0,`D?,+`/FS``#0]5L"J;4C`9'W8P.I]@,`JF/>1_GW`P&J````
MT.$#%:ID`$#YI"<(^00`@-(`H!&1<?C_EQ\``'%M!0!4`@0`4;0/`/FA``#0
MH\IB."'01_DX`$"Y@P,`-.(#`"I4?$"3X06`4N(#%*K@`Q6J)OG_E\`"`+3@
M`Q@JL_C_E^,#%*KB`Q6JX0,6JB?Y_Y>T#T#Y<]Y'^:$G2/E@`D#Y(```RJ`"
M`+7U6T*I$`J"TO=C0ZG]>T"I\PM`^?]C,(O``U_6'R`#U<+\_S6T#T#YX`,8
M*IWX_Y?B`Q>JX0,6JGKX_Y?L__\7H```T`#01_D8`$"Y]___%[0/`/FC^/^7
M_7N_J:```-#]`P"1`-!'^0``0+F-^/^7H@``T`,``-#]>\&H`0``T$+,1_EC
M8!"1(>`1D<GX_Q?]>[ZI_0,`D?,+`/FS``#0<])'^6`"0+E^^/^7Z___EV`"
M0+E[^/^7\PM`^?U[PJ@$``#0A"`?D0(``+`!``#0!0"`4N,#!*I"8#J1(6`2
MD=#X_Q<?(`/5$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&IM```T/5;`JFV`P"+
M@-Y'^;/C`)$!`$#YH2<0^0$`@-(P^/^7Y`,`*@4``-`#``#0I<`2D6/@$I$B
M`(+2(0"`4N`#$ZKW]_^7`@""TN$#%JK@`Q.J__?_EP`#^#?S`P"J``0`$0!\
M0),B^/^7]0,`JL```+1S?D"3X0,6JN(#$ZK8]_^7OVHS.)3>1_G@`Q6JHB=0
M^8$"0/E!``'*(0$`M?-30:D0"H32]5M"J?U[0*G_8S"+P`-?UA4`@-+S__\7
M2/C_EQ\@`]7(__\7'R`#U1`.@M+_8S#+_7L`J?T#`)'U6P*IM@``T/-3`:GU
M`P&JPMY'^?,#`*JADP&1````T$,`0/FC-PCY`P"`T@`@$Y'"_?^7]`,`JN$%
M@%+@`Q.JA/C_ER`"`+0```#0X0,3J@!@$Y$G_O^7X`,3JM;>1_FB-TCYP0)`
M^4$``<JA#0"U\U-!J1`.@M+U6T*I_7M`J?]C,(O``U_6MQL`^>`#$ZJY(P#Y
M%P``T+LK`/FE]_^7X:(3D?D#`"K@`Q6JG??_E_L#`*K@"@"TN!\`^;6C`9&Z
M)P#Y&```T!H``-`8PQ.16D,1D6`#0#D`!P`TM```M.$#&ZK@`Q2J)OC_ER`%
M`#3@`QNJC_?_EV'#((LA\%\X/[P`<>$``%0`!`!18<,@BW_+(#@A\%\X/[P`
M<6#__U0A!P`1(```"Q_\/W',`P!4Y`,;JKL``-`"`(+2(0"`4N8#$ZKE`QBJ
M`P``T.`#%:ICX!.1>_?_EWO31_E@`T"YV/?_EP(`")'A`Q6J``"`4GSW_Y?@
M```U8`-`N='W_Y<`$$*Y``P4$A\@0'%@`@!4X:(3D0``@-)B]_^7^P,`JJ#Y
M_[6W8T.IN6M$J;LK0/FF__\7'R`#U;0``+3A`QJJX`,4JN_W_Y=`_O\T^P,:
MJB``@%+3__\7(0"`4N`#%:K<]_^78/W_->$#%:H```#0`&`3D;_]_Y?@`Q6J
MN??_E[LK0/FW8T.IN6M$J93__Q>W&T#YN2-`^;LK0/F+__\7MV,#J;EK!*F[
M*P#YM??_EP$`0#GB`P"JP0``-``$`)$_O`!Q0A"`F@$`0#F!__\UX`,"JL`#
M7]:`"`"T_7N^J?T#`)'S4P&I\P,`JA0`0#D4`P`T+_?_EP`$`-%B`@"+?P("
MZ^(#`%1@:F`X'[P`<:```%08```40`!`.1^\`'&A`@!40@0`T7\"`NMA__]4
MG[X`<>```%3S4T&I````L/U[PJ@`P!.1AO?_%Q\@`]7S4T&I````L/U[PJ@`
M0!&1@/?_%Q\@`]5``$`Y'[P`<8`!`%1"!`#1?P("ZV/__U1_`@+K8/W_5$($
M`-%_`@+KX@``5$``0#D?O`!Q@0``5$($`-%_`@+K8___5$(`$\M`"`"1'P1`
M\0@"`%2D``#0A*`"D0,`@M)"!`"1X0,3JN`#!*HS]_^7\U-!J?U[PJC``U_6
M'R`#U0```+``0!&17/?_%Q\@`]4``(#2]___%_U[N*D!``"P(6`0D0```+#]
M`P"1\U,!J;,``+#U6P*I```4D6/>1_D6``"P]V,#J1<``+`F'$&I8@!`^:(_
M`/D"`(#2)!1"J:8?!:DA8$!Y&```L*'C`'D4``"PI!<&J92"%9&U,P&1&/W_
MEP```+``0!21%?W_EP```+``8!21$OW_EP```+``H!21#_W_E\#"%)$-_?^7
M````L```%9$*_?^7X"(3D0C]_Y<`0Q61!OW_E^`#%*H$_?^7````L`#`%9$!
M_?^7````L`!@$Y'^_/^7````L.$#%:H``!:1MOS_EX```+3A`P"JX`,4JB#]
M_Y<```"PX0,5J@!@%I&N_/^7H```M`(``+#A`P"J0,`6D1?]_Y<```"PX0,5
MJ@``%Y&E_/^70`(`M.$#`*K@(A.1#_W_EP$``+#`PA21(>`7D0O]_Y=SWD?Y
MH3]`^6`"0/D@``#*0`,`M?-30:GU6T*I]V-#J?U[R*C``U_6````L.$#%:H`
M0!>1C_S_EX`!`+4!``"PM$,!D4(!@-(AH!>1H(<!D<[V_Y?@_/\U@6X`D0!#
M%9'R_/^7X___%^$#`*H`0Q61[OS_E]___Q?P]O^7'R`#U?U[O:G]`P"1\U,!
MJ;,``+"T``#08=Y'^8`20+DB`$#YHA<`^0(`@-(?!``Q(`$`5'/>1_FB%T#Y
M80)`^4$``<HA`@"U\U-!J?U[PZC``U_6H9,`D0```+``0!619?S_E^$#`*H`
M`(!2H0``M"``0#D?P`!Q!!A`>N`'GQJ`$@"Y[/__%\WV_Y?]>[^I_0,`D6[V
M_Y?M]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7_7N[J?T#`)'S"P#YLP``
ML/5;`JD5``"P]QL`^;<"&)%BWD?Y]@,`JJ$3`9'@`Q>J0P!`^:,G`/D#`(#2
M0?S_EV`!`+2T#P#Y]`,`J@$`0#G!```TX0,6JASW_Y<@`@"TM`]`^04``!2T
M#T#YX0,6JJ`"&)&A_/^7<]Y'^:$G0/E@`D#Y(```RJ`#`+7U6T*I\PM`^?<;
M0/G]>\6HP`-?UN`#%JHE]O^7]0,`JN`#%*HB]O^7H`(`BP`(`)%7]O^7Y@,4
MJN0#%JH%``"P`P``L*6@$Y%CX!.1`@"`DO4#`*HA`(!2&?;_E^$#%:K@`Q>J
M@OS_E[0/0/G@__\7M`\`^8+V_Y<?(`/5$#J0TO]C,,NJ``#02D$`D0L$D-+]
M>P&I_4,`D:T#"XM$E4"I]5L#J;8``+#W(P#Y^B\`^?<#`*KS$P#YM3,"D<S>
M1_D:``"P0`5#J8X!0/FNS0#Y#@"`TD(-0JF@!PVI1AU$J:07":E()46IH@\,
MJ4L-0/GA`Q6J2C%`^4`C$Y&F'PZIJ*<*J:M3`/FJ7P#YZOO_EX```+0!`$`Y
M\P,`J@$3`#6T#P#YN.<#J;LK`/F(__^7]`,`J@`3`+3@`Q2JW/7_EP#X?],`
M!`"1$?;_EX0"0#GY`P"JA`$`-````+#S`QFJ&&`8D>`#$ZKC`QBJ`@"`DB$`
M@%+2]?^7<PH`D80>0#@D__\UH&-`^6`+`+2X`P.1,P"`T@8``!0?(`/5<P8`
MD0`/$XL`@%_X8`H`M.$#%:K!^_^7]`,`JB#__[0!`$`YX?[_-"#]_Y>@_O\T
MX`,4JB/V_Y?[`P"JX`@`M.`#&ZJS]?^7\P,`JN`#&:JP]?^7$P`3"W,2$!$8
M``"P<WY`D^`#$ZKB]?^7YP,9J@7#$Y'D`QNJ!@``L`,``+#&@!B18Z`8D0(`
M@)+T`P"J(0"`4J/U_Y<!.(!2X`,4JHSV_Y<?!``QH0``5('V_Y<%`$"YOT0`
M<<$,`%2[``"P>]-'^6`#0+GV]?^7`@`(D>$#%*H``(!2.O;_E_D#`"H`!@`T
MH```L.,"0/GD`Q2J`@``L`#(1_E"`!J1(0"`4A,`@-(``$#Y$O;_E[0/0/FX
MYT.INRM`^=;>1_D!!)#2H0,!B^`#$ZHBS$#YP0)`^4$``<JA.0"U]5M#J1`Z
MD-+]>T&I\Q-`^?<C0/GZ+T#Y_V,PB\`#7]:X0P*1%`"`4A/;=/BS`0"T8`)`
M.6`!`#3@`Q.JE`8`$<S\_Y<@__\TX`,3JL_U_Y?[`P"JH/7_M1/;=/BS_O^U
M&P"`TJG__Q=@`T"YO_7_EP`00KD`#!02'Q!`<8'Y_U2\+P#Y8`-`N;CU_Y<<
M&$*Y:O7_EY\#`&O`!0!4O"]`^</__Q<?(`/5_O[_E^`#$ZJV]?^7\P,`JLK_
M_Q<?(`/5N*,"D1,`@%(`VW/X@`$`M.$#%:IS!@`10OO_EV#__[0!`$`Y(?__
M-*CU_Y?T`P"JH.O_M0#;<_C`_O^UH`&`TF[U_Y<4``"P^0,`JF0*@%*40AB1
M7/__%Z```+#C`D#YY`,4J@(``+``R$?Y0N`8D2$`@%(3`(#2``!`^;?U_Y>T
M#T#YN.=#J;LK0/FE__\78`-`N87U_Y<`$$*Y`"``$A\`!W'!^?]4X`,3JE/U
M_Y?A`Q6J\P,`J@```+``X!F1&/O_ER`+`+3U`D#Y?_7_E^$#`*K@`Q6J0/W_
ME_4#`*I`"@"TX`,5J@SU_Y?[`P"J'PP`<>T!`%0`?$"3`0``L``0`-$A8!N1
MH`(`BY?U_Y<``0`U?Q,`<<`C`%1@$P!1H,(@BP#P7S@?O`!Q(",`5(#^_Y?`
M```U`0"`4N`#%:K.]?^7H'<`N4`'`#4!``"P(>`7D0```+``0!617_O_EQC#
M$Y$A]?^7%0``L+4B'Y'F`P`J`P``L.<#%:KE`QBJY`,4JF/@&Y$"`("2(0"`
M4N`#$ZH7``"PY/3_E_<B')$2```4'R`#U<3U_Y<``$"Y'T0`<4$"`%0,]?^7
M]0,`^3D'`!'F`P`JYP,9*N4#&*KD`Q2JXP,7J@(`@)(A`(!2X`,3JM'T_Y<!
M.(!2X`,3JKKU_Y<?!``Q@/W_5.`#%*IV]?^7X0,3JD`C$Y$S^_^7X`,3JG/^
M_Y>T#T#YN.=#J;MS1:D___\7]0)`^:[__Q>CXP:10@"`4O4#`ZHA`H"2HS\`
M^1'U_Y>@=T"YP@"`TN$#%:J!]?^7H.-&.8```#6@YT8Y'PP!<>`<`%2@=T"Y
M`@"`4@$`@-*YPP.1O*,$D0+U_Y>__Q&I(.,`D21@A-(C<972PI^;TL&.BM*@
M-P#Y`#Z<TJ3HK/*C^;WR0A>S\D$&HO)`>KCRI`\/J:('$*F_:P&YH(L`^:!W
M0+D"`)#2H3]`^6'U_Y?C`P"J]0,`*A\``'&M"`!4I8M1J6%\0).@:T&YI`P!
M"[\`!.M"E(*:071!BZ2'$:D`%``T`0B`4C4``$NA/T#Y?P`5:Z(W0/EUT)4:
MNWY`DZ,S`/E`P""+X@,;JFWT_Y>@:T&YHS-`^:`"``N@:P&Y'P`!<>'[_U2@
M/T#Y=0`52QL`&XO@`QFJ./;_E[_^`''-`@!4M0(!4:!^!E.@8P"Y%V0:4_<"
M`9%W`Q>+8`="J8`'`JED%T"IA!<`J6(/0:F"#P&I9A]#J88?`ZE[`P&1X`,9
MJB7V_Y?_`AOK@?[_5*!C0+FU&@!+H#=`^0,)@-*B?D"3X0,;JH+T_Y>U:P&Y
MH'=`N0(`D-*A/T#Y'?7_E^,#`*KU`P`J'P``<:SW_U2@=T"YO_3_E[7?4:GB
M#X`2H2(#4R`$`!$?X`!Q@LLA.(P-`%0CXP"1`@>`4D(``$L!`(!20GQ`DV#`
M((N)]/^7X?Y8T^#^4-.A@P4YH?Y8TZ"'!3G@_DC3H(L%.:#^4-.@EP4YH/Y(
MT[>/!3F\(P:1H9,%.9NC`)&UGP4Y]0,<JJ";!3G@`QFJ\/7_E[G'!9&F%T^I
M````L*,+4*D78!B1H8M`^<C\4-/'_$C3H/Q8TZG\4-.HQP4YI\L%.:C\2--G
M_%C3H-,%.6#\2-/$?!A3IL\%.6K\4-.IUP4Y)OQ8TZC;!3E)_%C32/Q0TZ7?
M!3FGXP4Y)?Q0TT?\2-.@ZP4YI,,%.2#\2-.JYP4YH^\%.:GS!3FH]P4YI_L%
M.:+_!3FF`P8YI0<&.:`+!CFA#P8Y`P``%!\@`]4D%T`XX`,5JN,#%ZH"`("2
M(0"`4K4*`)'X\_^7?P,5ZP'__U0'``"PY@,<JN<@'Y$#``"PO\,&.07#$Y'D
M`Q2J8Z`;D0(`@)(A`(!2X`,3JNKS_Y<>__\7NS]`^7;__Q?W!D#Y]]S_M.`#
M%ZK?\_^7'PP`\6G<_U0`$`#1`0``L.`"`(LA@!N1;/3_EQ\``'&U$I>:V_[_
M%P((@%)"``!+0GQ`DP$`@%([XP"18,,@BQ[T_Y?@`QFJEO7_EZ"#")$?_#"I
M/_\$J3__!:D_-P#YCO__%Z#K1CD?!`%Q`>/_5*#O1CD?#`%QH>+_5*#S1CD?
M(`%Q0>+_5*#W1CD?%`%QX>'_5+=W0+E"`(!2(0>`DN`#%RH1]/^7M3]`^2(%
M@-+@`Q<JX0,5JH#T_Y<'``"PY@,5J@,``+#G(!^1O___%[CG`ZF[<P6IM`\`
M^1OT_Y?]>[BIH```L/T#`)'W&P#YMP``L/-3`:GSTD?Y]5L"J;73`9'Z)P#Y
M`-Q'^;4S`/D!`$#YH3\`^0$`@-)@`D"Y^O/_E_0#`*I@`D"Y]_/_EX'B0CD!
MY`(Y````L.$#%:H`P!21C_G_EX```+0!`$`Y/\0`<2`4`%2<_/^7]M)'^<`"
M0+GI\_^7`0``L&,!@%(B`(!2(8`<D?SS_Y<@%@"TN!\`^:$``-`U(`*1H3<`
M^0$(0/G:`D"YH`9`N3@40/D?!`!Q[1D`5+DC`/D9@(!2NW,%J10`@%(S`(!2
M&02@<@L``!0?(`/580A`^>`#'*K^\_^7H09`N2`$`#5S!@`1E`8`$3\`$VNM
M`P!4X`,:*L;S_Y<#`(!2@GY`D^$#&*HJ]/^7^P,`JH`3`+0#`$#YI`9`^=H"
M0+E@#$"YG-AS^```&0H?`!!Q`/W_5.`#&BJV\_^780-`^4,`@%("`(#2HO/_
ME^$#`*K@`QRJW_/_E]H"0+FA!D"Y(/S_-"`$`%$?`!1K(`P`5+CG0ZF[<T6I
MX`,:*J7S_Y=C`(!2`0``D"(`@%(AH!R1N//_E_,#`*J@`0"T]-)'^8`"0+F;
M\_^780I`^0(``)!"P!R1(0!`^7;S_Y=@"D#Y``!`^0`,0+E`$+`W]-)'^8`"
M0+F/\_^7`0``D&,`@%(B`(!2(>`<D:+S_Y?S`P"JH`$`M*$S0/D```"0`&`3
MD2+Y_Y?U`P"J@`)`N?4,`+2`\_^780I`^>(#%:HA`$#Y7//_E_?21_F@-T#Y
M%"`"D>`"0+EW\_^7\P,`JN`"0+ET\_^7(@"`4@$``)`A`!V1K//_EP(``)#A
M`P"J0F`=D>`#$ZI+\_^7X`)`N6GS_Y<?Y`(YH3-`^0```)``(!.1`OG_EX`*
M`/GS`P"J8`8`M`$X@%+@`Q.JZO/_EP$$`!$_!`!Q!(A1>J$*`%2@``"0&MQ'
M^:$_0/E``T#Y(```RH`)`+7S4T&I]5M"J?<;0/GZ)T#Y_7O(J,`#7]8?(`/5
M``1`.0#L_S1>__\7'R`#U3\$`''M\_]4H#=`^3,`@%+UTD?Y%"`"D0,``!0?
M(`/5N@)`N>`#&BH^\_^7X0,8JOCR_Y>`!D"Y<P8`$1\`$VL,__]4X-)'^;CG
M0ZF[<T6I&@!`N8W__Q>@``"PV@)`N:`W`/F)__\7@`9`^;W\_Y>`"@#Y\P,`
MJD#Y_[4```"0N.<#J;MS!:D`@!V19?/_EZ$W0/G@TD?Y(2`"D2$$0+D:`$"Y
M(`0`41\`%&NA[O]4U/__%Q\@`]4:\_^7H#=`^6(*0/D`(`*1`01`^4``0/DA
M`$#Y._K_EY?__Q<?(`/5@`)`N0_S_Y=A"D#Y(0!`^63S_Y=Z__\7N!]`^6/_
M_Q>XYP.INW,%J1;S_Y>A-T#YXP,`*KMS!:GB`Q.J/"`"D;CG`ZD!``"0("`>
MD8$'0/DA`$#Y._/_E_U[OJG]`P"1\U,!J?0#`*I<^_^7`0!`.?,#`*K!```T
M``0`D3^\`'%S$H":`0!`.8'__S4/_/^7GP(`\0080'J!``!4\U-!J?U[PJC`
M`U_6@`)`.8#__S0!``"0@@"`TB&`&)'@`Q.JQ/+_E\#^_S7@`Q2J\U-!J?U[
MPJAW^?\7HP``D&/@1_F#``"T8P!`^9;R_Q<?(`/5`P"`TI/R_Q?]>[RI_0,`
MD?37`:FT``"0M0``D)0"+)&UXBN1]M\"J90"%<OX'P#YE/Y#D_8#`"KW`P&J
M^`,"JD;R_Y>4`0"TLPL`^1,`@-*C>G/XX@,8JN$#%ZK@`Q8J<P8`D6``/]:?
M`A/K(?__5+,+0/GTUT&I]M]"J?@?0/G]>\2HP`-?UL`#7];]>[^I_0,`D?U[
MP:C``U_6``````$``@``````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@```````````N`````````"XN````````
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P
M<F]C+R5I+R5S``````!005)?5$5-4```````````4$%27U!23T=.04U%````
M`#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),
M3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P``````
M``!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%2
M7T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````
M````,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A
M<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H```````!0051(
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````
M<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0Q
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````"5S````````+64````````M+0``
M`````%5315(`````55-%4DY!344``````````%1-4$1)4@``5$5-4$1)4@!4
M14U0`````%1-4```````+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM
M;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY
M("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O
M9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q
M<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@
M/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D
M(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T
M.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@
M)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R
M."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X]
M(#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N
M<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D
M8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P
M-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\
M(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@
M)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*
M9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<
M421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX[
M"B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[
M"G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I
M;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O
M<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H
M*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N
M;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A
M(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@
M)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F
M:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@
M=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?
M1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O
M7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E
M<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E
M;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F
M:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0[
M"GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@
M9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C
M;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D
M9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@
M86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE
M(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D
M<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT
M:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL
M92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M
M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',[
M"F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4"0````````()`````````$`
M`````````0`````````!`````````,L!`````````0````````#6`0``````
M``$`````````X`$````````!`````````"\"`````````0````````"(`P``
M``````$`````````L`,````````,`````````,@<````````#0````````#\
M4P```````!D`````````^)H!```````;``````````@`````````&@``````
M````FP$``````!P`````````"`````````#U_O]O`````&`"````````!0``
M``````"@#0````````8`````````4`,````````*`````````!4%````````
M"P`````````8`````````!4````````````````````#`````````%B=`0``
M`````@``````````!@```````!0`````````!P`````````7`````````,@6
M````````!P````````#X$P````````@`````````T`(````````)````````
M`!@`````````'@`````````(`````````/O__V\``````0``"`````#^__]O
M`````)@3````````____;P`````#`````````/#__V\`````MA(```````#Y
M__]O`````!$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#@'````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M`.`<````````X!P```````#@'````````.`<````````X!P```````#@'```
M`````.`<````````X!P```````#@'````````.`<````````X!P```````#@
M'````````.`<````````X!P```````#@'````````.`<````````X!P`````
M``#@'````````.`<````````X!P```````#@'````````.`<````````X!P`
M``````#@'````````.`<````````X!P```````#@'````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M``B;`0``````^%,`````````````````````````````````````````````
M````````````````````````````````````````````````"*`!````````
M`````````'A3````````````````````(0``````````````````````````
M````````````````````````"*`!``````#_____`````"!8````````4%0`
M`````````````````+!5`````````%@````````(6````````!!8````````
M&%@``````````````````.A7````````\%<``````````````````"A8````
M````1T-#.B`H1&5B:6%N(#<N,BXP+3$X*2`W+C(N,```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D
M871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0````(```````````(``````````@```````!L`````
M```````````````!````````````````````$P````<````"`````````!P"
M````````'`(````````@````````````````````!```````````````````
M`"$````'`````@`````````\`@```````#P"````````)```````````````
M``````0````````````````````T````]O__;P(`````````8`(```````!@
M`@```````.P`````````!0`````````(````````````````````/@````L`
M```"`````````%`#````````4`,```````!0"@````````8````#````"```
M```````8`````````$8````#`````@````````"@#0```````*`-````````
M%04```````````````````$```````````````````!.````____;P(`````
M````MA(```````"V$@```````-P`````````!0`````````"``````````(`
M````````6P```/[__V\"`````````)@3````````F!,```````!@````````
M``8````#````"````````````````````&H````$`````@````````#X$P``
M`````/@3````````T`(````````%``````````@`````````&`````````!T
M````!````$(`````````R!8```````#(%@`````````&````````!0```!0`
M```(`````````!@`````````?@````$````&`````````,@<````````R!P`
M```````4````````````````````!````````````````````'D````!````
M!@````````#@'````````.`<````````(`0``````````````````!``````
M````$`````````"$`````0````8``````````"$`````````(0```````/PR
M```````````````````(````````````````````B@````$````&````````
M`/Q3````````_%,````````0````````````````````!```````````````
M`````)`````!`````@`````````05````````!!4````````4$``````````
M``````````@```````````````````"8`````0````(`````````8)0`````
M``!@E`````````0````````````````````$````````````````````H@``
M``X````#`````````/B:`0``````^)H````````(````````````````````
M"``````````(`````````*X````/`````P``````````FP$```````";````
M````"`````````````````````@`````````"`````````"Z````!@````,`
M````````")L!```````(FP```````%`"````````!@`````````(````````
M`!``````````PP````$````#`````````%B=`0``````6)T```````"H`@``
M````````````````"``````````(`````````,@````!`````P``````````
MH`$```````"@````````@`````````````````````@`````````````````
M``#.````"`````,`````````@*`!``````"`H````````"@0````````````
M```````(````````````````````TP````$````P````````````````````
M@*`````````=`````````````````````0`````````!``````````$````#
M`````````````````````````)V@````````W`````````````````````$`
.````````````````````
